import zxcvbn from "zxcvbn";
import { openBlock, createBlock, createVNode, mergeProps, toDisplayString, createCommentVNode, withModifiers } from "vue";
var PasswordStrengthMeter_vue_vue_type_style_index_0_lang = '[v-cloak] {\n  display: none;\n}\n.Password {\n  max-width: 400px;\n  margin: 0 auto;\n}\n.Password__group {\n  position: relative;\n}\n.Password__strength-meter {\n  position: relative;\n  height: 3px;\n  background: #DDD;\n  margin: 10px auto 20px;\n  border-radius: 3px;\n}\n.Password__strength-meter:before, .Password__strength-meter:after {\n  content: "";\n  height: inherit;\n  background: transparent;\n  display: block;\n  border-color: #FFF;\n  border-style: solid;\n  border-width: 0 5px 0 5px;\n  position: absolute;\n  width: 20%;\n  z-index: 10;\n}\n.Password__strength-meter:before {\n  left: 20%;\n}\n.Password__strength-meter:after {\n  right: 20%;\n}\n.Password__strength-meter--fill {\n  background: transparent;\n  height: inherit;\n  position: absolute;\n  width: 0;\n  border-radius: inherit;\n  transition: width 0.5s ease-in-out, background 0.25s;\n}\n.Password__strength-meter--fill[data-score="0"] {\n  background: darkred;\n  width: 20%;\n}\n.Password__strength-meter--fill[data-score="1"] {\n  background: orangered;\n  width: 40%;\n}\n.Password__strength-meter--fill[data-score="2"] {\n  background: orange;\n  width: 60%;\n}\n.Password__strength-meter--fill[data-score="3"] {\n  background: yellowgreen;\n  width: 80%;\n}\n.Password__strength-meter--fill[data-score="4"] {\n  background: green;\n  width: 100%;\n}\n.Password__field {\n  background-color: #f1f1f1;\n  border: 1px solid #f1f1f1;\n  border-radius: 2px;\n  box-sizing: border-box;\n  font-size: 14px;\n  padding: 13px;\n  width: 100%;\n}\n.Password__field--disabled {\n  background-color: #f6f6f6;\n  border: 1px solid #f6f6f6;\n}\n.Password__icons {\n  position: absolute;\n  top: 0;\n  right: 0;\n  height: 100%;\n  display: flex;\n  flex-direction: row;\n  justify-content: flex-end;\n  align-items: center;\n}\n.Password__toggle {\n  line-height: 1.1;\n  margin-right: 13px;\n}\n.Password__badge {\n  position: relative;\n  color: white;\n  border-radius: 6px;\n  padding: 3px;\n  width: 30px;\n  height: 15px;\n  font-size: 14px;\n  line-height: 1.1;\n  margin-right: 13px;\n  display: flex;\n  justify-content: center;\n  align-items: center;\n}\n.Password__badge--error {\n  background: red;\n}\n.Password__badge--success {\n  background: #1bbf1b;\n}\n.btn-clean {\n  appearance: none;\n  background: none;\n  border: none;\n  cursor: pointer;\n  outline: none;\n  color: #777777;\n  padding: 0;\n}\n.btn-clean svg {\n  fill: currentColor;\n}\n.btn-clean:hover, .btn-clean:focus {\n  color: #404B69;\n}';
const _sfc_main = {
  name: "VuePasswordStrengthMeter",
  inheritAttrs: false,
  props: {
    modelValue: {
      type: String
    },
    secureLength: {
      type: Number,
      default: 7
    },
    badge: {
      type: Boolean,
      default: true
    },
    toggle: {
      type: Boolean,
      default: false
    },
    showPassword: {
      type: Boolean,
      default: false
    },
    referenceValue: {
      type: String,
      default: "input"
    },
    showStrengthMeter: {
      type: Boolean,
      default: true
    },
    strengthMeterOnly: {
      type: Boolean,
      default: false
    },
    defaultClass: {
      type: String,
      default: "Password__field"
    },
    disabledClass: {
      type: String,
      default: "Password__field--disabled"
    },
    errorClass: {
      type: String,
      default: "Password__badge--error"
    },
    successClass: {
      type: String,
      default: "Password__badge--success"
    },
    strengthMeterClass: {
      type: String,
      default: "Password__strength-meter"
    },
    strengthMeterFillClass: {
      type: String,
      default: "Password__strength-meter--fill"
    },
    labelShow: {
      type: String,
      default: "Show Password"
    },
    labelHide: {
      type: String,
      default: "Hide Password"
    },
    userInputs: {
      type: Array,
      default: () => []
    }
  },
  data() {
    return {
      password: null,
      _showPassword: false
    };
  },
  methods: {
    togglePassword() {
      if (this.$data._showPassword) {
        this.$emit("hide");
        this.$data._showPassword = false;
      } else {
        this.$emit("show");
        this.$data._showPassword = true;
      }
    },
    emitValue(type, value) {
      if (type === "input") {
        this.$emit("update:modelValue", value);
      } else {
        this.$emit(type, value);
      }
      this.password = value;
    }
  },
  computed: {
    passwordStrength() {
      return this.password ? zxcvbn(this.password, this.userInputs.length >= 1 ? this.userInputs : null).score : null;
    },
    isSecure() {
      return this.password ? this.password.length >= this.secureLength : null;
    },
    isActive() {
      return this.password && this.password.length > 0;
    },
    passwordCount() {
      return this.password && (this.password.length > this.secureLength ? `${this.secureLength}+` : this.password.length);
    },
    inputType() {
      return this.$data._showPassword || this.showPassword ? "text" : "password";
    },
    showPasswordLabel() {
      return this.$data._showPassword || this.showPassword ? this.labelHide : this.labelShow;
    }
  },
  watch: {
    modelValue(newValue) {
      if (this.strengthMeterOnly) {
        this.emitValue("input", newValue);
      }
      this.$emit("feedback", zxcvbn(newValue).feedback);
    },
    passwordStrength(score) {
      this.$emit("score", score);
    }
  }
};
const _hoisted_1 = { class: "Password" };
const _hoisted_2 = {
  key: 0,
  class: "Password__group"
};
const _hoisted_3 = { class: "Password__icons" };
const _hoisted_4 = {
  key: 1,
  class: "Password__toggle"
};
const _hoisted_5 = {
  key: 0,
  version: "1.1",
  xmlns: "http://www.w3.org/2000/svg",
  width: "24",
  height: "24",
  viewBox: "0 0 24 24"
};
const _hoisted_6 = /* @__PURE__ */ createVNode("path", { d: "M12 9c1.641 0 3 1.359 3 3s-1.359 3-3 3-3-1.359-3-3 1.359-3 3-3zM12 17.016c2.766 0 5.016-2.25 5.016-5.016s-2.25-5.016-5.016-5.016-5.016 2.25-5.016 5.016 2.25 5.016 5.016 5.016zM12 4.5c5.016 0 9.281 3.094 11.016 7.5-1.734 4.406-6 7.5-11.016 7.5s-9.281-3.094-11.016-7.5c1.734-4.406 6-7.5 11.016-7.5z" }, null, -1);
const _hoisted_7 = {
  key: 1,
  version: "1.1",
  xmlns: "http://www.w3.org/2000/svg",
  width: "24",
  height: "24",
  viewBox: "0 0 24 24"
};
const _hoisted_8 = /* @__PURE__ */ createVNode("path", { d: "M11.859 9h0.141c1.641 0 3 1.359 3 3v0.188zM7.547 9.797c-0.328 0.656-0.563 1.406-0.563 2.203 0 2.766 2.25 5.016 5.016 5.016 0.797 0 1.547-0.234 2.203-0.563l-1.547-1.547c-0.188 0.047-0.422 0.094-0.656 0.094-1.641 0-3-1.359-3-3 0-0.234 0.047-0.469 0.094-0.656zM2.016 4.266l1.266-1.266 17.719 17.719-1.266 1.266c-1.124-1.11-2.256-2.213-3.375-3.328-1.359 0.563-2.813 0.844-4.359 0.844-5.016 0-9.281-3.094-11.016-7.5 0.797-1.969 2.109-3.656 3.75-4.969-0.914-0.914-1.812-1.844-2.719-2.766zM12 6.984c-0.656 0-1.266 0.141-1.828 0.375l-2.156-2.156c1.219-0.469 2.578-0.703 3.984-0.703 5.016 0 9.234 3.094 10.969 7.5-0.75 1.875-1.922 3.469-3.422 4.734l-2.906-2.906c0.234-0.563 0.375-1.172 0.375-1.828 0-2.766-2.25-5.016-5.016-5.016z" }, null, -1);
function _sfc_render(_ctx, _cache, $props, $setup, $data, $options) {
  return openBlock(), createBlock("div", _hoisted_1, [
    !$props.strengthMeterOnly ? (openBlock(), createBlock("div", _hoisted_2, [
      createVNode("input", mergeProps(_ctx.$attrs, {
        type: $options.inputType,
        ref: $props.referenceValue,
        class: [$props.defaultClass, _ctx.$attrs.disabled ? $props.disabledClass : ""],
        value: $props.modelValue,
        onInput: _cache[1] || (_cache[1] = (evt) => $options.emitValue("input", evt.target.value)),
        onBlur: _cache[2] || (_cache[2] = (evt) => $options.emitValue("blur", evt.target.value)),
        onFocus: _cache[3] || (_cache[3] = (evt) => $options.emitValue("focus", evt.target.value))
      }), null, 16, ["type", "value"]),
      createVNode("div", _hoisted_3, [
        $props.badge ? (openBlock(), createBlock("div", {
          key: 0,
          class: [[$options.isSecure ? $props.successClass : "", !$options.isSecure && $options.isActive ? $props.errorClass : ""], "Password__badge"]
        }, toDisplayString($options.passwordCount), 3)) : createCommentVNode("", true),
        $props.toggle ? (openBlock(), createBlock("div", _hoisted_4, [
          createVNode("button", {
            type: "button",
            class: "btn-clean",
            "aria-label": $options.showPasswordLabel,
            tabindex: "-1",
            onClick: _cache[4] || (_cache[4] = withModifiers(($event) => $options.togglePassword(), ["prevent"]))
          }, [
            this.$data._showPassword ? (openBlock(), createBlock("svg", _hoisted_5, [
              createVNode("title", null, toDisplayString($options.showPasswordLabel), 1),
              _hoisted_6
            ])) : (openBlock(), createBlock("svg", _hoisted_7, [
              createVNode("title", null, toDisplayString($options.showPasswordLabel), 1),
              _hoisted_8
            ]))
          ], 8, ["aria-label"])
        ])) : createCommentVNode("", true)
      ])
    ])) : createCommentVNode("", true),
    $props.showStrengthMeter ? (openBlock(), createBlock("div", {
      key: 1,
      class: [$props.strengthMeterClass]
    }, [
      createVNode("div", {
        class: [$props.strengthMeterFillClass],
        "data-score": $options.passwordStrength
      }, null, 10, ["data-score"])
    ], 2)) : createCommentVNode("", true)
  ]);
}
_sfc_main.render = _sfc_render;
export default _sfc_main;
